##  CONFIGURATION_CREATED

```
{
  "type": "CONFIGURATION_CREATED",
  "userId": "3et65c21-98f2-5376-acaa-fchf654b9c22",
  "connectorId": "inbound-document-connector",
  "workspaceId": "ae6756f1-4aag-4356-92c6-a390a60cb8fg",
  "connectorType": "inboundDocument",
  "processingMode": "partial",
  "integrationType": "Integration API",
  "connectorVersion": "1.0.0",
  "processingDirection": "inbound"
}
```



